@@ -1,12 +1,12 @@
 use embedded_hal::{blocking::spi, digital::v2::OutputPin};
 
 use crate::{
+	configs,
 	ll,
 	mac,
 	time::{Duration, Instant},
 	Error,
 	DW3000,
-	configs,
 };
 use super::Awake;
 
@@ -91,7 +91,7 @@ where
 	/// Force the DW3000 into IDLE mode
 	///
 	/// Any ongoing RX/TX operations will be aborted.
-	pub(super) fn force_idle(&mut self, _double_buffered: bool) -> Result<(), Error<SPI, CS>> {
+	pub(super) fn _force_idle(&mut self, _double_buffered: bool) -> Result<(), Error<SPI, CS>> {
 		self.ll.fast_command(0)?;
 		Ok(())
 	}
