@@ -10,14 +10,14 @@ use super::AutoDoubleBufferReceiving;
 use crate::{
 	configs::SfdSequence,
 	time::Instant,
-	Error,
-	Ready,
 	Config,
+	Error,
+	FastCommand,
+	Ready,
 	Sending,
 	SingleBufferReceiving,
 	Sleeping,
 	DW3000,
-	FastCommand,
 };
 
 /// The behaviour of the sync pin
@@ -73,14 +73,10 @@ where
 	}
 
 	/// Sets the network id and address used for sending and receiving
-	pub fn set_address(
-		&mut self,
-		pan_id: mac::PanId,
-		addr: mac::ShortAddress,
-	) -> Result<(), Error<SPI, CS>> {
+	pub fn set_address(&mut self, pan_id: u16, addr: u16) -> Result<(), Error<SPI, CS>> {
 		self.ll
 			.panadr()
-			.write(|w| w.pan_id(pan_id.0).short_addr(addr.0))?;
+			.write(|w| w.pan_id(pan_id).short_addr(addr))?;
 
 		Ok(())
 	}
@@ -191,8 +187,8 @@ where
 		})?;
 
 		match send_time {
-			SendTime::Now => self.fast_cmd(FastCommand::CMD_TX)?,
-			_ =>  self.fast_cmd(FastCommand::CMD_DTX)?, // Start TX
+			| SendTime::Now => self.fast_cmd(FastCommand::CMD_TX)?,
+			| _ => self.fast_cmd(FastCommand::CMD_DTX)?, // Start TX
 		}
 
 		Ok(DW3000 {
@@ -267,5 +263,4 @@ where
 		self.ll.sys_enable().write(|w| w)?;
 		Ok(())
 	}
-	
 }
