@@ -12,11 +12,11 @@ use crate::{
 	configs::{BitRate, SfdSequence},
 	mac,
 	time::Instant,
-	Error,
-	Ready,
 	Config,
-	DW3000,
+	Error,
 	FastCommand,
+	Ready,
+	DW3000,
 };
 use super::{AutoDoubleBufferReceiving, Receiving};
 
@@ -71,7 +71,6 @@ where
 	}
 
 	pub(super) fn start_receiving(&mut self, config: Config) -> Result<(), Error<SPI, CS>> {
-
 		if config.frame_filtering {
 			self.ll.sys_cfg().modify(
 				|_, w| w.ffen(0b1), // enable frame filtering
@@ -139,8 +138,10 @@ where
 				return Err(nb::Error::Other(Error::PreambleDetectionTimeout))
 			}
 			if sys_status.rxsto() == 0b1 {
-				self.ll.sys_status().write(|w| w.rxsto(1))
-				.map_err(|error| nb::Error::Other(Error::Spi(error)))?;
+				self.ll
+					.sys_status()
+					.write(|w| w.rxsto(1))
+					.map_err(|error| nb::Error::Other(Error::Spi(error)))?;
 				return Err(nb::Error::Other(Error::SfdTimeout))
 			}
 			/*
@@ -233,14 +234,12 @@ where
 		Ok(Message { rx_time, frame })
 	}
 
-	
 	#[allow(clippy::type_complexity)]
 	/// Finishes receiving and returns to the `Ready` state
 	///
 	/// If the receive operation has finished, as indicated by `wait`, this is a
 	/// no-op. If the receive operation is still ongoing, it will be aborted.
 	pub fn finish_receiving(self) -> Result<DW3000<SPI, CS, Ready>, (Self, Error<SPI, CS>)> {
-
 		Ok(DW3000 {
 			ll:    self.ll,
 			seq:   self.seq,
